==> ukui-sidebar_3.0.1.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Display debug information</source>
        <translation>Hata Bildirimlerini Göster</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="177"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="180"/>
        <source>Set up notification center</source>
        <translation>Bildirim Merkezini Ayarla</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="112"/>
        <source>折叠</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="114"/>
        <source>展开</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>ClipBoard</source>
        <translation type="vanished">Pano</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="210"/>
        <source>Sidebar</source>
        <translation>Yan Panel</translation>
    </message>
</context>
<context>
    <name>sidebarPluginsWidgets</name>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="97"/>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="104"/>
        <source>Plugins</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>Notebook</source>
        <translation type="vanished">Notebook</translation>
    </message>
    <message>
        <source>Alarm clock</source>
        <translation type="vanished">Çalar Saat</translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation type="vanished">Geri Bildirim</translation>
    </message>
</context>
</TS>

==> ukui-sidebar_3.1.1.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Display debug information</source>
        <translation>Hata Bildirimlerini Göster</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="177"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="180"/>
        <source>Set up notification center</source>
        <translation>Bildirim Merkezini Ayarla</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="112"/>
        <source>折叠</source>
        <translation>Ayarla</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="114"/>
        <source>展开</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>ClipBoard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="210"/>
        <source>Sidebar</source>
        <translation>Yan Panel</translation>
    </message>
</context>
<context>
    <name>sidebarPluginsWidgets</name>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="97"/>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="104"/>
        <source>Plugins</source>
        <translation>Eklentiler</translation>
    </message>
    <message>
        <source>Notebook</source>
        <translation>Not Defteri</translation>
    </message>
    <message>
        <source>Alarm clock</source>
        <translation>Çalar Saat</translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation>Geri Bildirim</translation>
    </message>
</context>
</TS>
